Prints a human-readable formulation of a goal programming problem.
# S3 method for goalp
print(x, ...)A scalar character (i.e. a text string) with a human-readable
formulation of the goal programming problem represented by
goalp object x. This can be edited and used as an input
to goalp, if modifications to the goal programming problem
are required.
A goalp object.
Additional arguments. Ignored.